# AI Interactive Feedback v2025.0721.01 Release Notes

## 🚀 New Features

### Desktop Application Window Memory
- **Complete elimination of window size flickering** - Desktop app no longer shows window resizing during startup
- **Smart window configuration persistence** - Automatically remembers user's last window size and position
- **Seamless startup experience** - Every launch displays with user's preferred window configuration

## 🔧 Technical Improvements

### Window Initialization Optimization
- **Hide-Configure-Show mechanism** - Window starts hidden, gets configured, then displays smoothly
- **Automatic configuration management** - Window settings saved to `%APPDATA%/mcp-feedback-enhanced/window-config.json`
- **Real-time configuration sync** - User window adjustments automatically saved for next session

### Development Environment Support
- **Prioritize development builds** - Testing automatically uses latest debug version
- **Error fixes** - Resolved Tokio async context issues, eliminating runtime errors

## 📁 Affected Files

- `src-tauri/src/main.rs` - Core window memory logic implementation
- `src-tauri/tauri.conf.json` - Default window configuration optimization
- `src-tauri/Cargo.toml` - Added dirs dependency support
- `desktop_app.py` - Improved executable file discovery logic
- `desktop_release/mcp-feedback-enhanced-desktop.exe` - Updated desktop application

## 🎯 User Experience Improvements

### Optimized Startup Flow
1. Window starts in hidden state, avoiding default size display
2. Automatically loads previously saved window configuration
3. Applies correct window size and position
4. Smoothly displays window without any flickering
5. User window adjustments automatically saved for future use

### Compatibility Assurance
- **First-run friendly** - Automatically calculates suitable window size when no config exists
- **Cross-platform support** - Windows, macOS, Linux all support window memory functionality
- **Backward compatible** - Existing users automatically receive window memory feature upon upgrade

## 🔄 Upgrade Instructions

Upgrading from previous versions to v2025.0721.01:

1. **Automatic upgrade** - New features available automatically when installing via `uvx`
2. **Configuration migration** - First launch automatically creates window configuration file
3. **No manual setup required** - All window memory functionality enabled automatically

## 💻 Technical Details

### Configuration File Format
```json
{
  "width": 1260,
  "height": 850,
  "x": 100,
  "y": 50
}
```

### New Dependencies
- `dirs = "5.0"` - Cross-platform configuration directory management

---

This release significantly improves the desktop application user experience by eliminating the long-standing window size flickering issue, providing users with a more professional and smooth desktop application experience.